==> anywhereSSL_0.3.2.zip: anywhereSSL/include/precheck.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// ľܸƤӽФ줿exit
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslPreCheck') ) {

	/**
	 * awsslPreCheck
	 * 
	 * @param void
	 * @return void
	 */
	function awsslPreCheck() {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );
		
		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {
		
			//*************************************************************************/
			// ⥸塼ܾ
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );
			
			//*************************************************************************/
			// ɺѤߤåԤ
			//*************************************************************************/
			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;
			
			//*************************************************************************/
			// åΥåȤԤ
			//*************************************************************************/
			$Anywheressl->setSecureCookie();
			
			//*************************************************************************/
			// ɺѤߤǤʤ硢̤
			//*************************************************************************/
			if ( ! $awssl_loaded ) {
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = !empty( $_SERVER['QUERY_STRING'] ) ? '?' .$_SERVER['QUERY_STRING'] : '';
				header( "Location: " .$current_script .$query_string );
			}
			
			//*************************************************************************/
			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
			//*************************************************************************/
			$session_regenerate_id = ( $awssl_config['session_regenerate_id']['conf_value'] === 'yes' ) ? true : false;
			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );

			//*************************************************************************/
			// SSL-Loginοƥɥν񤭴
			//*************************************************************************/
			$current_url = $Anywheressl->getCurrentUrl();
			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
				include_once( $mod_path .'/include/sslloginbuf.inc.php' );
			}
		} else {
			//*************************************************************************/
			// ܶػߥե饰
			//*************************************************************************/
			if ( ! defined( 'AWSSL_CANNOT_DESTINE' ) ) {
				define( 'AWSSL_CANNOT_DESTINE', 1 );
			}
		}
	}

	awsslPreCheck();

}


?>

==> anywhereSSL_0.3.4.zip: anywhereSSL/include/precheck.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// ľܸƤӽФ줿exit
//*****************************************************************************/
if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

if ( ! function_exists('awsslPreCheck') ) {

	/**
	 * awsslPreCheck
	 * 
	 * @param void
	 * @return void
	 */
	function awsslPreCheck() {
		//*****************************************************************************/
		// 
		//*****************************************************************************/
		include( dirname(dirname(__FILE__)) .'/init.php' );
		
		//*****************************************************************************/
		// ⥸塼꤬Ǥʤϥå
		//*****************************************************************************/
		if ( ! empty($awssl_config) ) {
		
			//*************************************************************************/
			// ⥸塼ܾ
			//*************************************************************************/
			include( $mod_path .'/class/anywheressl.class.php' );
			$Anywheressl = new Anywheressl( $awssl_config );
			
			//*************************************************************************/
			// ɺѤߤåԤ
			//*************************************************************************/
			$awssl_loaded = !empty( $_SESSION['AWSSL_LOADED'] ) ? true : false;
			
			//*************************************************************************/
			// åΥåȤԤ
			//*************************************************************************/
			$Anywheressl->setSecureCookie();
			
			//*************************************************************************/
			// ɺѤߤǤʤ硢̤
			//*************************************************************************/
			if ( ! $awssl_loaded ) {
				$current_script = basename($_SERVER['SCRIPT_FILENAME']);
				$query_string = !empty( $_SERVER['QUERY_STRING'] ) ? '?' .$_SERVER['QUERY_STRING'] : '';
				header( "Location: " .$current_script .$query_string );
			}
			
			//*************************************************************************/
			// 奢°ղáʥåIDڤؤ"Ϥ"ξڤؤ
			//*************************************************************************/
			$session_regenerate_id = ( $awssl_config['session_regenerate_id']['conf_value'] === 'yes' ) ? true : false;
			$Anywheressl->awsslSessionRegenerateId( $regenerate = $session_regenerate_id );

			//*************************************************************************/
			// SSL-Loginοƥɥν񤭴
			//*************************************************************************/
			$current_url = $Anywheressl->getCurrentUrl();
			if ( $current_url === XOOPS_URL .'/misc.php?action=showpopups&type=ssllogin' ) {
				include_once( $mod_path .'/include/sslloginbuf.inc.php' );
			}
		} else {
			//*************************************************************************/
			// ܶػߥե饰
			//*************************************************************************/
			if ( ! defined( 'AWSSL_CANNOT_DESTINE' ) ) {
				define( 'AWSSL_CANNOT_DESTINE', 1 );
			}
		}

		//*****************************************************************/
		// URLΥꥢ
		//*****************************************************************/
		if ( dirname(strtr($_SERVER['SCRIPT_FILENAME'], $replace_array)) !== $mod_replace_path ) {
			unset( $_SESSION['AWSSL_DESTINATION'] );
		}
	}

	awsslPreCheck();

}


?>
